@@ -1,15 +1,16 @@
+import argparse
+from dataclasses import dataclass
 from pathlib import Path
 
-from PIL import Image
-from dataclasses import dataclass
-import argparse
 import numpy as np
+from PIL import Image
 
-from wavelets.lifting_step import Wavelet
+from wavelets.coiflet import coiflet1, coiflet2
 from wavelets.db import db4_wavelet, db8_wavelet, db2_wavelet
 from wavelets.haar import haar_wavelet
-from wavelets.symlets import symlets2, symlets4, symlets8
 from wavelets.io import save_decomposed_img, read_decomposed_img
+from wavelets.lifting_step import Wavelet
+from wavelets.symlets import symlets2, symlets4, symlets8
 from wavelets.transform import wt_2d, wt_2d_inv
 
 
@@ -27,16 +28,20 @@ def main():
     parser = argparse.ArgumentParser(
         description='Integer wavelet decomposition')
     group = parser.add_mutually_exclusive_group(required=True)
-    group.add_argument('-d', '--decomposition', action='store_true', help="Decompose the image.")
-    group.add_argument('-r', '--reconstruction', action='store_true', help="Reconstruct the image.")
+    group.add_argument('-d', '--decomposition', action='store_true',
+                       help="Decompose the image.")
+    group.add_argument('-r', '--reconstruction', action='store_true',
+                       help="Reconstruct the image.")
 
     parser.add_argument('-i', '--input', required=True,
                         help='Path to the mandatory input file')
     parser.add_argument('-o', '--output', help='Path to the output file')
     parser.add_argument('-w', '--wavelet',
                         choices=[
-                            'Haar', 'Daubechie2', 'Daubechie4', 'Daubechie8',
+                            'Haar',
+                            'Daubechie2', 'Daubechie4', 'Daubechie8',
                             'Symlets2', 'Symlets4', 'Symlets8',
+                            'Coiflet1', 'Coiflet2',
                         ],
                         required=True, help='Wavelet type', default='Haar')
     parser.add_argument('-l', '--level', type=int, required=True,
@@ -61,13 +66,19 @@ def main():
             wavelet = symlets4()
         case 'Symlets8':
             wavelet = symlets8()
+        case 'Coiflet1':
+            wavelet = coiflet1()
+        case 'Coiflet2':
+            wavelet = coiflet2()
         case _:
-            # Note: This should not happen, since argparse checks validity of wavelets
+            # Note: This should not happen, since argparse checks validity of
+            # wavelets
             raise RuntimeError("Unknown wavelet")
     configuration = ParsedConfig(
         wavelet=wavelet,
         path_in=args.input,
-        path_out=args.output if args.output else str(Path("./output.tif").resolve()),
+        path_out=args.output if args.output else str(
+            Path("./output.tif").resolve()),
         level=args.level,
         operation_decompose=True if args.decomposition else False
     )
@@ -82,7 +93,8 @@ def main():
             # images.
             print("Converting image to signed 32bit integer...")
             image = np.array(img_pil).astype(np.int32)
-        decomposition = wt_2d(image, configuration.wavelet, configuration.level)
+        decomposition = wt_2d(image, configuration.wavelet,
+                              configuration.level)
         save_decomposed_img(decomposition, configuration.path_out)
     else:
         if not configuration.path_out.endswith('.tif'):
